#
# spec file for package python-gunicorn
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-gunicorn
Version:        19.3.0
Release:        4.3.1
Summary:        WSGI HTTP Server for UNIX
License:        MIT
Group:          Development/Languages/Python
Url:            http://gunicorn.org
Source:         http://pypi.python.org/packages/source/g/gunicorn/gunicorn-%{version}.tar.gz
Patch0:         CVE-2018-1000164.patch
BuildRequires:  fdupes
BuildRequires:  python-Sphinx
BuildRequires:  python-devel
BuildRequires:  python-mock
BuildRequires:  python-pytest
BuildRequires:  python-pytest-cov
BuildRequires:  python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
BuildRequires:  python-unittest2
%else
BuildArch:      noarch
%endif

%description
Gunicorn 'Green Unicorn' is a Python WSGI HTTP Server for UNIX. It's a pre-fork
worker model ported from Ruby's Unicorn_ project. The Gunicorn server is broadly
compatible with various web frameworks, simply implemented, light on server
resource usage, and fairly speedy.

%package        doc
Summary:        WSGI HTTP Server for UNIX - Documentation
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description doc
This package contains Gunicorn documentation in reST and HTML formats.

%prep
%setup -q -n gunicorn-%{version}
# remove version pinning for test requirements
sed -i 's/==.*//' requirements_test.txt
%patch0 -p1

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# install documentation and examples
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -r LICENSE NOTICE README.rst THANKS examples %{buildroot}%{_docdir}/%{name}
cd docs && make SPHINXBUILD=sphinx-build html && rm -r build/html/.buildinfo # Generate HTML documentation
cp -r build/html %{buildroot}%{_docdir}/%{name}

%fdupes %{buildroot}%{_prefix}

%check
python setup.py -q test

%files
%defattr(-,root,root,-)
%exclude %{_docdir}/%{name}/html
%exclude %{_docdir}/%{name}/examples
%doc %dir %{_docdir}/%{name}/
%doc %{_docdir}/%{name}/*
%{_bindir}/gunicorn*
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc %dir %{_docdir}/%{name}/html
%doc %dir %{_docdir}/%{name}/examples
%doc %{_docdir}/%{name}/html/*
%doc %{_docdir}/%{name}/examples/*

%changelog
* Mon Apr  9 2018 jsegitz@suse.com
- Fix for CVE-2018-1000164: Improper neutralization of CRLF Sequences
  can allow an attacker to cause a server to return arbitrary HTTP
  headers (boo#1088613)
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 19.3.0:
  * fix: issue 978 make sure a listener is inheritable
  * add check_config class method to workers
  * fix: issue 983 fix select timeout in sync worker with multiple
    connections
  * allows workers to access to the reloader. close issue 984
  * raise TypeError instead of AssertionError
  * make Logger.loglevel a classs attribute
  * fix: issue 988 fix syntax errors in examples/gunicorn_rc
- additional changes from version 19.2.1:
  * expose loglevel in the Logger class
  * fix issue 977 fix initial crash
  * document security mailing-list in the contributing page
- additional changes from version 19.2:
  * optimize the sync workers when listening on a single interface
  * add –sendfile settings to enable/disable sendfile. fix issue 856
  * add the selectors module to the code base. issue 886
  * add –max-requests-jitter setting to set the maximum jitter to
    add to the max-requests setting
  * fix issue 899 propagate proxy_protocol_info to keep-alive
    requests
  * fix issue 863 worker timeout: dynamic timeout has been removed
  * fix: Avoid world writable file
  * fix issue 941 set logconfig default to paster more trivially
  * add statsd-prefix config setting: set the prefix to use when
    emitting statsd metrics
  * issue 832 log to console by default
  * fix issue 908 make sure the worker can continue to accept
    requests
  * fix issue 867 Fix eventlet shutdown to actively shut down the
    workers
- remove python-nose from BuildRequires: unneeded
- add python-mock and python-pytest-cov as test dependencies
- add python-unittest2 as test dependencies for SLE11
- remove version pinning for test requirements with sed
- reenable the tests
- move documentation files under the main package docdir
* Thu Dec 11 2014 axel.braun@gmx.de
- update to version 19.1.1
    fix #835: display correct pid of already running instance
    fix : fix PyTest class in setup.py.
    fix #838: statsd logegr, send statsd timing metrics in milliseconds
    fix #839: statsd logger, allows for empty log message while pushing metrics and restore worker number in DEBUG logs
    fix #850: add timezonw to logging
    fix #853: Respect logger_class setting unless statsd is on
    fix #830 make sure gaiohttp worker is shipped with gunicorn.
    fix #785: handle binary type address given to a client socket address
    fix graceful shutdown. make sure QUIT and TERMS signals are switched everywhere.
    support loading config from module (#799)
    fix check for file-like objects (#805)
    fix #815 args validation in WSGIApplication.init
    fix #787 check if we load a pyc file or not.
    fix #771: support tornado 4.0
    fix #783: x_headers error. The x-forwarded-headers option has been removed in c4873681299212d6082cd9902740eef18c2f14f1. The discussion is available on #633.
    fix: fetch all body in input. fix #803
    fix: don’t install the worker if python < 3.3
    fix #822: Support UNIX sockets in gaiohttp worker
    fix #790 StopIteration shouldn’t be catched at this level.
    add statsd logging handler fix #748
    fix #809 Set global logging configuration from a Paste config.
    fix RuntimeError in gunicorn.reloader (#807)
    update faq: put a note on how watch logs in the console since many people asked for it.
    details see http://docs.gunicorn.org/en/19.1.1/news.html#id1
- remove test
* Tue Dec 10 2013 p.drouand@gmail.com
- Update to version 18.0
  + new: add -e/--env command line argument to pass an environment
    variables to gunicorn
  + new: add --chdir command line argument to specified directory
    before apps loading. - new: add wsgi.file_wrapper support in
    async workers
  + new: add --paste command line argument to set the paster config file
  + deprecated: the command gunicorn_django is now deprecated. You
    should now run your application with the WSGI interface installed
    with your project
    (see https://docs.djangoproject.com/en/1.4/howto/deployment/wsgi/gunicorn/)
    for more infos.
  + deprecated: the command gunicorn_paste is deprecated. You now should
    use the new --paste argument to set the configuration file of your
    paster application.
  + fix: Removes unmatched leading quote from the beginning of the
    default access log format string
  + fix: null timeout
  + fix: gevent worker
  + fix: don’t reload the paster app when using pserve
  + fix: after closing for error do not keep alive the connection
  + fix: responses 1xx, 204 and 304 should not force the connection
    to be closed
- Changes from 17.5
  + new: add signals documentation
  + new: add post_worker_init hook for workers
  + new: try to use gunicorn.conf.py in current folder as the default
    config file.
  + fix graceful timeout with the Eventlet worker
  + fix: don’t raise an error when closing the socket if already closed
  + fix: fix –settings parameter for django application and try to find
    the django settings when using the gunicorn command.
  + fix: give the initial global_conf to paster application
  + New versionning: With this release, the versionning of Gunicorn is
    changing. Gunicorn is stable since a long time and there is no point
    to release a “1.0” now. It should have been done since a long time.
    0.17 really meant it was the 17th stable version. From the beginning
    we have only 2 kind of releases:
  - major release: releases with major changes or huge features added
    services releases: fixes and minor features added So from now we
    will apply the following versionning <major>.<service>.
    For example 17.5 is a service release.
- Changes from 0.17.4
  + fix unix socket address parsing
- Changes from 0.17.3
  + add systemd sockets support
  + add python -m gunicorn.app.wsgiapp support
  + improve logger class inheritance
  + exit when the config file isn’t found
  + add the -R option to enable stdio inheritance in daemon mode
  + don’t close file descriptors > 3 in daemon mode
  + improve STDOUT/STDERR logging
  + fix pythonpath option
  + fix pidfile creation on Python 3
  + fix gevent worker exit
  + fix ipv6 detection when the platform isn’t supporting it
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Jan 14 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to 0.17.2:
  * optimize readline()
  * make import errors more visible
  * don't pass ssl_options if there are any
  * don't accept str or unicode in the body
- Build documentation from source with python-Sphinx
- Remove duplicate files with fdupes
* Tue May 15 2012 suse@ammler.ch
- update to version 0.14.3
  - improvement: performance of http.body.Body.readline()
  - improvement: log HTTP errors in access log like Apache
  - improvment: display traceback when the worker fails to boot
  - improvement: makes gunicorn work with gevent 1.0
  - examples: websocket example now supports hybi13
  - fix: reopen log files after initialization
  - fix: websockets support
  - fix: django1.4 support
  - fix: only load the paster application 1 time
* Thu Mar 22 2012 suse@ammler.ch
- Update to version 0.14.2
  - add validate_class validator: allows to use a class or a method
    to initialize the app during in-code configuration
  - add support for max_requests in tornado worker
  - add support for disabling x_forwarded_for_header in tornado worker
  - gevent_wsgi is now an alias of gevent_pywsgi
  - Fix gevent_pywsgi worker
* Sat Mar 10 2012 saschpe@gmx.de
- Fix doc package summary
* Sat Mar 10 2012 saschpe@gmx.de
- Update to version 0.14.1
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 0.13.4:
- Run testsuite
- BuildRequire python-distribute instead of python-setuptools
- Package examples, LICENSE, NOTICE, README.rst, THANKS
* Fri Sep 23 2011 suse@ammler.ch
- upstream update 0.13.3
  * fix util.closerange function used to prevent leaking fds on
    python 2.5 (typo)
- update to 0.13.2
  * refactor gevent worker
  * prevent leaking fds on reexec
  * fix inverted request_time computation
* Thu Aug 25 2011 suse@ammler.ch
- upstream update 0.13.1
  * Fix unix socket. log argument was missing.
- update to 0.13.0
  * Improve logging: allows file-reopening and add access log file
    compatible with the apache combined log format
  * Add the possibility to set custom SSL headers.
    X-Forwarded-Protocol and X-Forwarded-SSL are still the default
  * New on_reload hook to customize how gunicorn spawn new workers on SIGHUP
  * Handle projects with relative path in django_gunicorn command
  * Preserve path parameters in PATH_INFO
  * post_request hook now accepts the environ as argument.
  * When stopping the arbiter, close the listener asap.
  * Fix Django command run_gunicorn in settings reloading
  * Fix Tornado worker exiting
  * Fix the use of sendfile in wsgi.file_wrapper
* Fri Jul  8 2011 ammler@openttdcoop.org
- spec header
- dropped _service
- support for SLE_11
* Sat Jul  2 2011 ammler@openttdcoop.org
- initial package of version 0.12.2
